#!/bin/sh
# test we are root
if [ "$(id -u)" != "0" ]; then
   echo "run as root now exitting"
   exit 1
fi

CFLAGS="gcc -flto -fuse-linker-plugin -mtune=generic -Os -pipe"
CXX="g++ -flto -fuse-linker-plugin -mtune=generic -Os -pipe -fno-exceptions -fno-rtti" 

P=mtpaint-gtk3
V=3.50
SRC=mtpaint-$V
USER=`cat /etc/sysconfig/tcuser`

LIST="submitqc compiletc gtk3-dev giflib7-dev libjpeg-turbo-dev lcms2-dev libwebp1-dev openjpeg-dev tiff-dev "
for Z in $LIST
    do 
    su -c "tce-load -i $Z" $USER
done

cd /tmp
su -c "/usr/local/bin/wget -nc --no-check-certificate \
https://sourceforge.net/projects/mtpaint/files/mtpaint/3.50/mtpaint-3.50.tar.bz2  "  $USER
tar jxvf $mtpaint*bz2
cd $SRC
./configure --prefix=/usr/local thread asneeded gtk3 intl jpeg jp2v2 lcms2 tiff webp  
################
#Version 3.50
# System              GNU/Linux
# Toolkit             GTK+3
# Lists               GTK+2
# File Picker         mtpaint
# Colour Picker       mtpaint
# Animation Package   Gifsicle
# Use FreeType        YES
# Use CMS             LittleCMS2
# Icon set            icons1
# Internationalized   YES
# Multithreaded       YES
#Compiler
# Optimizations       YES
# CFLAGS              -O2  -fcommon
# LDFLAGS             -Wl,--as-needed -s 
# Static libraries    NONE
#File Types
# Use GIF             GIF
# Use JPEG            YES
# Use JPEG 2000       OpenJPEG2
# Use TIFF            YES
# Use WebP            YES
#Installation
# Binary install      /usr/local/bin
# Locale install      /usr/local/share/locale
# Locale program      /usr/local/share/locale
# Install man page    NO

############################################
make -j5 # about 15 sec
# install-strip fails
make install DESTDIR=/tmp/$P
cd /tmp

# locale
######
mkdir -p $P-locale/usr/local/share
mv $P/usr/local/share/locale $P-locale/usr/local/share

# main
######

APP=$P/usr/local/share/applications
mkdir -p $APP
echo '[Desktop Entry]
Name=mtpaint
Exec=mtpaint
Terminal=false
Icon=mtpaint
X-FullPathIcon=/usr/local/share/pixmaps/mtpaint.png
MimeType=image/bmp;image/gif;image/x-portable-bitmap;image/x-portable-graymap;image/x-portable-pixmap;image/x-xbitmap;image/x-xwindowdump;image/x-xcf;image/x-compressed-xcf;image/tiff;image/jpeg;image/png;image/x-icon;image/webp
StartupNotify=false
Type=Application
Categories=Graphics;GTK; ' > $APP/$P.desktop

mkdir -p $P/usr/local/share/doc/$P
echo 'GPL v3' > $P/usr/local/share/doc/$P/COPYING

# TCZ them
###########
LIST="$P $P-locale "
for Z in $LIST
do
	mksquashfs $Z $Z.tcz
	md5sum $Z.tcz > $Z.tcz.md5.txt
	cd $Z
	find usr -not -type d > /tmp/$Z.tcz.list
        sed 's|usr|/usr|g' -i /tmp/$Z.tcz.list
	cd /tmp
done

ls -hal

echo 'Title:          mtpaint-gtk3-locale.tcz
Description:    mtpaint locales
Version:        3.50
Author:         Dmitry Groshev
Original-site:  https://sourceforge.net/projects/mtpaint
Copying-policy: GPL v3
Size:           436K                  		
Extension_by:   you
Tags:           locales
Comments:       locales might also work for gtk1 mtpaint
                untested by me

Change-log:     2023/03/15 first version 3.50
Current:        2023/03/15  ' > $P-locale.tcz.info

echo 'Title:          mtpaint-gtk3.tcz
Description:    paint tool
Version:        3.50
Author:         Dmitry Groshev
Original-site:  https://sourceforge.net/projects/mtpaint
Copying-policy: GPL v3
Size:           496K                  		
Extension_by:   you
Tags:           paint gif jpeg 2000 png tiff webp  
Comments:       paint and image converter
                original author Mark Tyler and 
                contributors

                Conflicts with mtpaint (gtk1)

Change-log:     2023/03/15 first version 3.50
Current:        2023/03/15   ' > $P.tcz.info

readelf -d $P/usr/local/bin/mtpaint | grep 'NEEDED'
#0x0000000000000001 (NEEDED) Shared library: [libgif.so.7]     giflib7
#0x0000000000000001 (NEEDED) Shared library: [libopenjp2.so.7] openjpeg
#0x0000000000000001 (NEEDED) Shared library: [libwebp.so.7]    libwep1
#0x0000000000000001 (NEEDED) Shared library: [libtiff.so.5]     libtiff..gdk-pixbuf2...gtk3
#0x0000000000000001 (NEEDED) Shared library: [libjpeg.so.62]    libjpeg-turbo..libtiff..gdk-pixbuf2...gtk3
#0x0000000000000001 (NEEDED) Shared library: [libfreetype.so.6]  freetype
#0x0000000000000001 (NEEDED) Shared library: [liblcms2.so.2]     liblcms2
#0x0000000000000001 (NEEDED) Shared library: [libpng16.so.16]   libpng cairo...gtk3
#0x0000000000000001 (NEEDED) Shared library: [libz.so.1]         TCB      
#0x0000000000000001 (NEEDED) Shared library: [libm.so.6]          TCB
#0x0000000000000001 (NEEDED) Shared library: [libgtk-3.so.0]      gtk3
#0x0000000000000001 (NEEDED) Shared library: [libgdk-3.so.0]      gtk3
#0x0000000000000001 (NEEDED) Shared library: [libpangocairo-1.0.so.0] pango gtk3
#0x0000000000000001 (NEEDED) Shared library: [libpango-1.0.so.0]      pango gtk3
#0x0000000000000001 (NEEDED) Shared library: [libcairo.so.2]          cairo pango gtk3
#0x0000000000000001 (NEEDED) Shared library: [libgdk_pixbuf-2.0.so.0] gdk-pixbuf2 gtk3
#0x0000000000000001 (NEEDED) Shared library: [libgobject-2.0.so.0]    glib2 cairo..gtk3
#0x0000000000000001 (NEEDED) Shared library: [libglib-2.0.so.0]         "
#0x0000000000000001 (NEEDED) Shared library: [libX11.so.6]             libX11 gdk-pixbuf2..gtk3
#0x0000000000000001 (NEEDED) Shared library: [libc.so.6]                TCB

echo 'giflib7.tcz
openjpeg.tcz
libwebp1.tcz
gtk3.tcz
freetype.tcz
liblcms2.tcz' > $P.tcz.dep

submitqc --libs
